<?php

namespace Article\Blog\Policies;

use Litepie\User\Contracts\UserPolicy;
use Article\Blog\Models\Article;

class ArticlePolicy
{

    /**
     * Determine if the given user can view the article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function view(UserPolicy $user, Article $article)
    {
        if ($user->canDo('blog.article.view') && $user->isAdmin()) {
            return true;
        }

        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can create a article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('blog.article.create');
    }

    /**
     * Determine if the given user can update the given article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function update(UserPolicy $user, Article $article)
    {
        if ($user->canDo('blog.article.edit') && $user->isAdmin()) {
            return true;
        }

        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Article $article)
    {
        return $article->user_id == user_id() && $article->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Article $article)
    {
        if ($user->canDo('blog.article.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given article.
     *
     * @param UserPolicy $user
     * @param Article $article
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Article $article)
    {
        if ($user->canDo('blog.article.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
